==> org.opennms.features.events.traps-17.0.1-20200407.181933-37-sources.jar: org/opennms/netmgt/trapd/TrapdIpMgr.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2002-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.trapd;

import java.sql.SQLException;

/**
 * <p>TrapdIpMgr interface.</p>
 *
 * @author ranger
 * @version $Id: $
 */
public interface TrapdIpMgr {

    /**
     * Clears and synchronizes the internal known IP address cache with the
     * current information contained in the database. To synchronize the cache
     * the method opens a new connection to the database, loads the address, and
     * then closes it's connection.
     *
     * @throws java.sql.SQLException
     *             Thrown if the connection cannot be created or a database
     *             error occurs.
     */
    void dataSourceSync() throws SQLException;

    /**
     * Returns the nodeid for the IP Address
     *
     * @param addr
     *            The IP Address to query.
     * @return The node ID of the IP Address if known.
     */
    long getNodeId(String addr);

    /**
     * Sets the IP Address and Node ID in the Map.
     *
     * @param addr
     *            The IP Address to add.
     * @param nodeid
     *            The Node ID to add.
     * @return The nodeid if it existed in the map.
     */
    long setNodeId(String addr, long nodeid);

    /**
     * Removes an address from the node ID map.
     *
     * @param addr
     *            The address to remove from the node ID map.
     * @return The nodeid that was in the map.
     */
    long removeNodeId(String addr);

}

==> org.opennms.features.events.traps-19.0.0-20160713.194721-102-sources.jar: org/opennms/netmgt/trapd/TrapdIpMgr.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2002-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.trapd;


/**
 * <p>TrapdIpMgr interface.</p>
 *
 * @author ranger
 * @version $Id: $
 */
public interface TrapdIpMgr {

    /**
     * Clears and synchronizes the internal known IP address cache with the
     * current information contained in the database. To synchronize the cache
     * the method opens a new connection to the database, loads the address, and
     * then closes it's connection.
     *
     * @throws java.sql.SQLException
     *             Thrown if the connection cannot be created or a database
     *             error occurs.
     */
    void dataSourceSync();

    /**
     * Returns the nodeid for the IP Address
     *
     * @param addr
     *            The IP Address to query.
     * @return The node ID of the IP Address if known.
     */
    int getNodeId(String addr);

    /**
     * Sets the IP Address and Node ID in the Map.
     *
     * @param addr
     *            The IP Address to add.
     * @param nodeid
     *            The Node ID to add.
     * @return The nodeid if it existed in the map.
     */
    int setNodeId(String addr, int nodeid);

    /**
     * Removes an address from the node ID map.
     *
     * @param addr
     *            The address to remove from the node ID map.
     * @return The nodeid that was in the map.
     */
    int removeNodeId(String addr);

    /**
     * Method will check value for null. 
     * @param result
     * @return If result is null returns -1 else returns result itself 
     */
    int intValue(Integer result);

}
